# {{ project_name }}

Generated by `azure-functions-scaffold`.

Template: `ai`

Preset: `{{ preset_name }}`

Python: `{{ python_version }}`

## Development

```bash
python -m venv .venv
. .venv/bin/activate
pip install -e .{% if include_ruff or include_mypy or include_pytest %}[dev]{% endif %}
{% if include_ruff -%}
ruff check .
ruff format --check .
{% endif -%}
{% if include_mypy -%}
mypy .
{% endif -%}
{% if include_pytest -%}
pytest
{% endif -%}
func start
```

## Local AI development

Set `AZURE_OPENAI_ENDPOINT`, `AZURE_OPENAI_API_KEY`, and `AZURE_OPENAI_DEPLOYMENT`
in `local.settings.json` before running the app locally.
