# {{ project_name }}

Generated by `azure-functions-scaffold`.

Preset: `{{ preset_name }}`

Python: `{{ python_version }}`
{% if include_openapi %}

OpenAPI: enabled — visit `/api/docs` for Swagger UI
{% endif %}
{% if include_validation %}

Validation: enabled — request/response models validated via `azure-functions-validation`
{% endif %}

## Development

```bash
python -m venv .venv
. .venv/bin/activate
pip install -e .{% if include_ruff or include_mypy or include_pytest %}[dev]{% endif %}
{% if include_ruff -%}
ruff check .
ruff format --check .
{% endif -%}
{% if include_mypy -%}
mypy .
{% endif -%}
{% if include_pytest -%}
pytest
{% endif -%}
func start
```
{% if include_openapi %}

## API Documentation

Once the function app is running, open the following URLs:

- Swagger UI: `http://localhost:7071/api/docs`
- OpenAPI JSON: `http://localhost:7071/api/openapi.json`
- OpenAPI YAML: `http://localhost:7071/api/openapi.yaml`
{% endif %}
